0.9.9 API documentation: matrix_float4x4.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

matrix_float4x4.hpp File Reference

Core features More...

Go to the source code of this file.

typedef mat< 4, 4, float, defaultp > | mat4x4
| 4 columns of 4 components matrix of single-precision floating-point numbers. More...
typedef mat< 4, 4, float, defaultp > | mat4
| 4 columns of 4 components matrix of single-precision floating-point numbers. More...

## Detailed Description

Core features

Definition in file matrix_float4x4.hpp.